# Shooker
Tool for C-code injections in already compiled bins.

## Usage
Write hook config as described in the [instruction](https://github.com/ReKreker/shooker/blob/master/docs/hooks%20xml.md).

```shooker --xml config.xml target_dir/ output_dir/```

## Install
```pip install shooker```<br />
**Please read about [common errors](https://github.com/ReKreker/shooker/blob/master/docs/common%20errors.md)**
